@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -32,7 +32,7 @@ class WP3AttributeGroup : public WP3FixedLengthGroup
 {
  public:
 	WP3AttributeGroup(WPXInputStream *input, uint8_t groupID);	
-	virtual void parse(WP3HLListener *listener);
+	virtual void parse(WP3Listener *listener);
 	
  protected:
 	virtual void _readContents(WPXInputStream *input);
