@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -28,7 +28,7 @@
 #include "WPXParser.h"
 
 class WPXHLListenerImpl;
-class WP3HLListener;
+class WP3Listener;
 
 class WP3Parser : public WPXParser
 {
@@ -38,10 +38,10 @@ public:
 
 	virtual void parse(WPXHLListenerImpl *listenerImpl);
 	
-	static void parseDocument(WPXInputStream *input, WP3HLListener *listener);
+	static void parseDocument(WPXInputStream *input, WP3Listener *listener);
 
 private:
-	void parse(WPXInputStream *input, WP3HLListener *listener);
+	void parse(WPXInputStream *input, WP3Listener *listener);
 };
 
 #endif /* WP3PARSER_H */
