@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -42,7 +42,7 @@ WP5AttributeOnGroup::WP5AttributeOnGroup(WPXInputStream *input, uint8_t groupID)
 {
 }
 
-void WP5AttributeOnGroup::parse(WP5HLListener *listener)
+void WP5AttributeOnGroup::parse(WP5Listener *listener)
 {
 	listener->attributeChange(true, getAttribute());
 }
@@ -52,7 +52,7 @@ WP5AttributeOffGroup::WP5AttributeOffGroup(WPXInputStream *input, uint8_t groupI
 {
 }
 
-void WP5AttributeOffGroup::parse(WP5HLListener *listener)
+void WP5AttributeOffGroup::parse(WP5Listener *listener)
 {
 	listener->attributeChange(false, getAttribute());
 }
