@@ -1,6 +1,7 @@
 /* libwpd
  * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
  * Copyright (C) 2003 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2005 Fridrich Strba (fridrich.strba@bluewin.ch)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,7 +15,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -26,7 +27,7 @@
 #ifndef WP5FILESTRUCTURE_H
 #define WP5FILESTRUCTURE_H
 
-// size of the fixed length functiongroups 0xC0 to 0xCF
+/* size of the fixed length functiongroups 0xC0 to 0xCF */
 extern int WP5_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16]; 
 
 #define WP5_ATTRIBUTE_EXTRA_LARGE 0x00
@@ -53,7 +54,10 @@ extern int WP5_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP5_TOP_ATTRIBUTE_OFF 0xC4
 #define WP5_TOP_PAGE_FORMAT_GROUP 0xD0
 #define WP5_TOP_FONT_GROUP 0xD1
+#define WP5_TOP_DEFINITION_GROUP 0xD2
 #define WP5_TOP_FORMAT_GROUP 0xD4
+#define WP5_TOP_TABLE_EOL_GROUP 0xDC
+#define WP5_TOP_TABLE_EOP_GROUP 0xDD
 
 /* Page Format Group */
 #define WP5_TOP_PAGE_FORMAT_GROUP_LEFT_RIGHT_MARGIN_SET 0x01
@@ -69,4 +73,42 @@ extern int WP5_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 /* Format Group */
 #define WP5_FORMAT_GROUP_END_OF_PAGE 0x00
 
+/* Definition Group */
+#define WP5_TOP_DEFINITION_GROUP_DEFINE_TABLES 0x0B
+
+/* Table EOL Group */
+#define WP5_TABLE_EOL_GROUP_BEGINNING_OF_COLUMN_AT_EOL 0x00
+#define WP5_TABLE_EOL_GROUP_BEGINNING_OF_ROW_AT_EOL 0x01
+#define WP5_TABLE_EOL_GROUP_TABLE_OFF_AT_EOL 0x02
+
+/* Table EOP Group */
+#define WP5_TABLE_EOP_GROUP_BEGINNING_OF_ROW_AT_EOP 0x01
+#define WP5_TABLE_EOP_GROUP_TABLE_OFF_AT_EOP 0x02
+#define WP5_TABLE_EOP_GROUP_BEGINNING_OF_ROW_AT_HARD_EOP 0x03
+
+/* Extended Character */
+#define WP5_INTERNATIONAL_1_CHARACTER_SET 1
+#define WP5_INTERNATIONAL_2_CHARACTER_SET 2
+#define WP5_BOX_DRAWING_CHARACTER_SET 3
+#define WP5_TYPOGRAPHIC_SYMBOL_CHARACTER_SET 4
+#define WP5_ICONIC_SYMBOL_CHARACTER_SET 5
+#define WP5_MATH_SCIENTIFIC_CHARACTER_SET 6
+#define WP5_MATH_SCIENTIFIC_EXTENDED_CHARACTER_SET 7
+#define WP5_GREEK_CHARACTER_SET 8
+#define WP5_HEBREW_CHARACTER_SET 9
+#define WP5_CYRILLIC_CHARACTER_SET 10
+#define WP5_JAPANESE_CHARACTER_SET 11
+
+#define WP5_NUM_INTERNATIONAL_1_CHARACTERS 234
+#define WP5_NUM_INTERNATIONAL_2_CHARACTERS 28
+#define WP5_NUM_BOX_DRAWING_CHARACTERS 88
+#define WP5_NUM_TYPOGRAPHIC_CHARACTERS 85
+#define WP5_NUM_ICONIC_CHARACTERS 35
+#define WP5_NUM_MATH_SCIENTIFIC_CHARACTERS 56
+#define WP5_NUM_MATH_SCIENTIFIC_EXTENDED_CHARACTERS 229
+#define WP5_NUM_GREEK_CHARACTERS 210
+#define WP5_NUM_HEBREW_CHARACTERS 44
+#define WP5_NUM_CYRILLIC_CHARACTERS 150
+#define WP5_NUM_JAPANESE_CHARACTERS 185
+
 #endif /* WP5FILESTRUCTURE_H */
