@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -28,9 +28,7 @@
 
 #include "WPXPart.h"
 #include "WPXParser.h"
-#include "WP5HLListener.h"
-
-class WP5LLListener;
+#include "WP5Listener.h"
 
 class WP5Part
 {
@@ -38,7 +36,7 @@ class WP5Part
 	virtual ~WP5Part() {}
 	
 	static WP5Part * constructPart(WPXInputStream *input, uint8_t readVal);
-	virtual void parse(WP5HLListener *listener) = 0;
+	virtual void parse(WP5Listener *listener) = 0;
 };
 
 #endif /* WP5PART_H */
