@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -28,6 +28,9 @@
 #include "WP5UnsupportedVariableLengthGroup.h"
 #include "libwpd_internal.h"
 #include "WP5FormatGroup.h"
+#include "WP5DefinitionGroup.h"
+#include "WP5TableEOLGroup.h"
+#include "WP5TableEOPGroup.h"
 
 WP5VariableLengthGroup::WP5VariableLengthGroup()
 {
@@ -39,8 +42,14 @@ WP5VariableLengthGroup * WP5VariableLengthGroup::constructVariableLengthGroup(WP
 	{
 		case WP5_TOP_FORMAT_GROUP:
 			return new WP5FormatGroup(input);
+		case WP5_TOP_DEFINITION_GROUP:
+			return new WP5DefinitionGroup(input);
 		case WP5_TOP_PAGE_FORMAT_GROUP:
 			return new WP5PageFormatGroup(input);
+		case WP5_TOP_TABLE_EOL_GROUP:
+			return new WP5TableEOLGroup(input);
+		case WP5_TOP_TABLE_EOP_GROUP:
+			return new WP5TableEOPGroup(input);
 		default:
 			// this is an unhandled group, just skip it
 			return new WP5UnsupportedVariableLengthGroup(input);
