@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -26,8 +26,7 @@
  */
 
 #include "WP6EOLGroup.h"
-#include "WP6LLListener.h"
-#include "WPXHLListener.h"
+#include "WPXListener.h"
 #include "libwpd_internal.h"
 
 #include "WP6Parser.h" // for TableException
@@ -76,7 +75,7 @@ void WP6EOLGroup::_readContents(WPXInputStream *input)
 	uint16_t sizeDeletableSubFunctionData;
 	unsigned int startPosition = input->tell();
 	sizeDeletableSubFunctionData = readU16(input);		
-	WPD_DEBUG_MSG(("WordPerfect: EOL Group: Size of Deletable Sub-Function Data: %ld,  Size of Deletable and Non-deletable sub-function data: %ld\n", (long) sizeDeletableSubFunctionData, getSizeNonDeletable()));
+	WPD_DEBUG_MSG(("WordPerfect: EOL Group: Size of Deletable Sub-Function Data: %ld,  Size of Deletable and Non-deletable sub-function data: %ld\n", (long) sizeDeletableSubFunctionData, (long) getSizeNonDeletable()));
 	input->seek(sizeDeletableSubFunctionData, WPX_SEEK_CUR);
 	while (input->tell() < (startPosition + getSizeNonDeletable()))
 	{
@@ -125,7 +124,7 @@ void WP6EOLGroup::_readContents(WPXInputStream *input)
 			case WP6_EOL_GROUP_CELL_INFORMATION:
 				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Sub-Function: CELL_INFORMATION\n"));
 				numBytesToSkip = WP6_EOL_GROUP_CELL_INFORMATION_SIZE;
-				uint8_t cellFlag, justification, tmpCellVerticalAlign;
+				uint8_t cellFlag, tmpCellVerticalAlign;
 				uint16_t attributeWord1, attributeWord2;
 				cellFlag = readU8(input);
 				if ((cellFlag & 0x01) == 0x01)
@@ -136,8 +135,7 @@ void WP6EOLGroup::_readContents(WPXInputStream *input)
 					m_ignoreInCalculations = true;
 				if ((cellFlag & 0x80) == 0x80)
 					m_cellIsLocked = true;
-				justification = readU8(input);	
-				m_cellJustification = (justification & 0x07);
+				m_cellJustification = (readU8(input) & 0x07);
 				tmpCellVerticalAlign = readU8(input);
 				switch (tmpCellVerticalAlign & 0x03)
 				{
@@ -168,7 +166,7 @@ void WP6EOLGroup::_readContents(WPXInputStream *input)
 				numCellsSpannedHorizontally = readU8(input);
 				numCellsSpannedVertically = readU8(input);
 				WPD_DEBUG_MSG(("WordPerfect: num cells spanned (h:%ld, v:%ld)\n", 
-						   numCellsSpannedHorizontally, numCellsSpannedVertically));
+						   (long) numCellsSpannedHorizontally, (long) numCellsSpannedVertically));
 				if (numCellsSpannedHorizontally >= 128)
 					m_boundFromLeft = true;
 				else
@@ -245,7 +243,7 @@ void WP6EOLGroup::_readContents(WPXInputStream *input)
 	}
 }
 
-void WP6EOLGroup::parse(WP6HLListener *listener)
+void WP6EOLGroup::parse(WP6Listener *listener)
 {
 	WPD_DEBUG_MSG(("WordPerfect: handling an EOL group\n"));
 
@@ -301,9 +299,13 @@ void WP6EOLGroup::parse(WP6HLListener *listener)
 			break;
 		case WP6_EOL_GROUP_TABLE_CELL: // Table Cell
 			WPD_DEBUG_MSG(("WordPerfect: EOL group: table cell\n"));
-			listener->insertCell(m_colSpan, m_rowSpan, m_boundFromLeft, m_boundFromAbove,
-					m_cellBorders, cellFgColor, cellBgColor, cellBorderColor, m_cellVerticalAlign, m_cellAttributes);
-			listener->justificationChange(m_cellJustification);
+			if (!m_boundFromLeft && !m_boundFromAbove)
+			{
+				listener->insertCell(m_colSpan, m_rowSpan, m_cellBorders, cellFgColor, cellBgColor,
+					cellBorderColor, m_cellVerticalAlign, m_useCellAttributes, m_cellAttributes);
+				if (m_useCellJustification)
+					listener->justificationChange(m_cellJustification);
+			}
 			break;
 		case WP6_EOL_GROUP_TABLE_ROW_AND_CELL:
 		case WP6_EOL_GROUP_TABLE_ROW_AT_EOC:
@@ -315,9 +317,13 @@ void WP6EOLGroup::parse(WP6HLListener *listener)
 			
 			listener->insertRow(m_rowHeight, m_isMinimumHeight, m_isHeaderRow);
 			// the cellBorders variable already represent the cell border bits as well
-			listener->insertCell(m_colSpan, m_rowSpan, m_boundFromLeft, m_boundFromAbove,
-					m_cellBorders, cellFgColor, cellBgColor, cellBorderColor, m_cellVerticalAlign, m_cellAttributes);
-			listener->justificationChange(m_cellJustification);
+			if (!m_boundFromLeft && !m_boundFromAbove)
+			{
+				listener->insertCell(m_colSpan, m_rowSpan, m_cellBorders, cellFgColor, cellBgColor,
+					cellBorderColor, m_cellVerticalAlign, m_useCellAttributes, m_cellAttributes);
+				if (m_useCellJustification)
+					listener->justificationChange(m_cellJustification);
+			}
 			break;
 		case WP6_EOL_GROUP_TABLE_OFF:
 		case WP6_EOL_GROUP_TABLE_OFF_AT_EOC:
