@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -26,7 +26,6 @@
 
 #include "WP6ExtendedCharacterGroup.h"
 #include "WP6FileStructure.h"
-#include "WP6LLListener.h"
 #include "libwpd_internal.h"
 
 WP6ExtendedCharacterGroup::WP6ExtendedCharacterGroup(WPXInputStream *input, uint8_t groupID) :
@@ -43,10 +42,10 @@ void WP6ExtendedCharacterGroup::_readContents(WPXInputStream *input)
 	m_characterSet = readU8(input);
 }
 
-void WP6ExtendedCharacterGroup::parse(WP6HLListener *listener)
+void WP6ExtendedCharacterGroup::parse(WP6Listener *listener)
 {
 	const uint16_t *chars;
-	int len = extendedCharacterToUCS2(m_character,
+	int len = extendedCharacterWP6ToUCS2(m_character,
 					  m_characterSet, &chars);
 	int i;
 
