@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -28,7 +28,7 @@
 
 #include "WPXPart.h"
 #include "WPXParser.h"
-#include "WP6HLListener.h"
+#include "WP6Listener.h"
 #include "WP6FileStructure.h"
 
 class WP6Part
@@ -37,7 +37,7 @@ class WP6Part
 	virtual ~WP6Part() {}
 	
 	static WP6Part * constructPart(WPXInputStream *input, uint8_t readVal);
-	virtual void parse(WP6HLListener *listener) = 0;
+	virtual void parse(WP6Listener *listener) = 0;
 };
 
 
