@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -24,7 +24,6 @@
  */
 
 #include "WP6UndoGroup.h"
-#include "WP6LLListener.h"
 #include "libwpd_internal.h"
 
 WP6UndoGroup::WP6UndoGroup(WPXInputStream *input, uint8_t groupID)
@@ -39,7 +38,7 @@ void WP6UndoGroup::_readContents(WPXInputStream *input)
 	m_undoLevel = readU16(input);
 }
 
-void WP6UndoGroup::parse(WP6HLListener *listener)
+void WP6UndoGroup::parse(WP6Listener *listener)
 {
 	listener->undoChange(m_undoType, m_undoLevel);
 }
