@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -27,6 +27,7 @@
 #define LIBWPD_INTERNAL_H
 #include "WPXStream.h"
 #include <stdio.h>
+#include <string>
 #include "WPXString.h"
 
 /* Various functions/defines that need not/should not be exported externally */
@@ -71,6 +72,8 @@ uint8_t readU8(WPXInputStream *input);
 uint16_t readU16(WPXInputStream *input, bool bigendian=false);
 uint32_t readU32(WPXInputStream *input, bool bigendian=false);
 
+std::string readPascalString(WPXInputStream *input);
+
 void appendUCS4(WPXString &str, uint32_t ucs4);
 
 // Various helper structures for the libwpd parser..
@@ -81,6 +84,8 @@ int extendedCharacterWP6ToUCS2(uint8_t character, uint8_t characterSet,
 int extendedCharacterWP5ToUCS2(uint8_t character, uint8_t characterSet,
 			    const uint16_t **chars);
 
+uint16_t fixedPointToWPUs(const uint32_t fixedPointNumber);
+
 enum WPXFileType { WP6_DOCUMENT, WP5_DOCUMENT, WP42_DOCUMENT, OTHER };
 enum WPXNumberingType { ARABIC, LOWERCASE, UPPERCASE, LOWERCASE_ROMAN, UPPERCASE_ROMAN };
 enum WPXNoteType { FOOTNOTE, ENDNOTE };
@@ -149,6 +154,8 @@ typedef struct _RGBSColor RGBSColor;
 struct _RGBSColor
 {
 	_RGBSColor(uint8_t r, uint8_t g, uint8_t b, uint8_t s);
+	_RGBSColor(uint16_t red, uint16_t green, uint16_t blue); // Construct
+	// RBBSColor from double precision RGB color used by WP3.x for Mac
 	_RGBSColor(); // initializes all values to 0
 	uint8_t m_r;
 	uint8_t m_g;
@@ -165,6 +172,14 @@ struct _WPXColumnDefinition
 	float m_rightGutter;
 };
 
+typedef struct _WPXColumnProperties WPXColumnProperties;
+struct _WPXColumnProperties
+{
+	_WPXColumnProperties();
+	uint32_t m_attributes;
+	uint8_t m_alignment;
+};
+
 typedef struct _WPXTabStop WPXTabStop;
 struct _WPXTabStop
 {
@@ -203,4 +218,12 @@ class UnsupportedEncryptionException
 	// needless to say, we could flesh this class out a bit
 };
 
+// Various usefull, but cheesey functions
+
+int _extractNumericValueFromRoman(const char romanChar);
+int _extractDisplayReferenceNumberFromBuf(const WPXString &buf, const WPXNumberingType listType);
+WPXNumberingType _extractWPXNumberingTypeFromBuf(const WPXString &buf, const WPXNumberingType putativeWPXNumberingType);
+WPXString _numberingTypeToString(WPXNumberingType t);
+
+
 #endif /* LIBWPD_INTERNAL_H */
